/*  
 * Copyright (c) 1998, Larry Lile
 * All rights reserved.
 *
 * For latest sources and information on this driver, please
 * go to http://anarchy.stdio.com.
 *
 * Questions, comments or suggestions should be directed to
 * Larry Lile <lile@stdio.com>.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice unmodified, this list of conditions, and the following
 *    disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $Id: if_tokreg.h,v 1.5 1998/07/12 17:37:05 lile Exp $
 *
 */

/*
 * IBM Shared Ram and TROPIC Token-Ring
 *
 *   Token-Ring Network PC Adapter
 *   Token-Ring Network PC Adapter II
 *   Token-Ring Network Adapter/A
 *   Token-Ring Network 16/4 Adapter/A (long card)
 *   Token-Ring Network 16/4 Adapter
 *   Token-Ring Network 16/4 Adapter/A (short card)
 *   16/4 ISA-16 Adapter
 *   Auto 16/4 Token-Ring ISA Adapter
 *   Auto 16/4 Token-Ring MC Adapter <-- Not supported currently
 *
 * $Revision: 1.5 $
 * 
 */

/*
 * Internal adapter status
 */
#define UNKNOWN 0xFF
#define RESET   0x00
#define READY   0x01

/*
 * Programmed IO areas for Primary and Alternate adapters
 */

#define PIO_PRI 0x0a20
#define PIO_ALT 0x0a24

/*
 * Interrupt level setup
 */

#define IRQ_MASK 0x3

#define GLOBAL_INT_ENABLE 0x2f0

#define IRQ2   0x0
#define IRQ3   0x1
#define IRQ6   0x2    /* Not availabel on MCA or Auto 16-4 */
#define IRQ7   0x3    /* Not availabel on MCA or Auto 16-4 */
#define IRQ9   IRQ2
#define IRQ10  IRQ6   /* MCA or Auto 16-4 ISA Adapter only */
#define IRQ11  IRQ7   /* MCA or Auto 16-4 ISA Adapter only */

/*
 * BIOS/MMIO Layout offsets
 */

#define BIOS_OFFSET   0x0
#define ACA_OFFSET    0x1e00
#define AIP_OFFSET    0x1f00
#define CH_ID_OFFSET  0x1f30
#define WRBR_OFFSET   0x1e02
#define WWOR_OFFSET   0x1e04
#define WWCR_OFFSET   0x1e06
#define ISRP_OFFSET   0x1e08
#define ISRA_OFFSET   0x1e0a
#define TCR_OFFSET    0x1e0c
#define TVR_OFFSET    0x1e0e
#define SRPR_OFFSET   0x1e18

/*
 * Interrupt Status Register Adapter pair (ISRA)
 *    used by the adapter to provide status to the driver (even)
 *    and for the driver to interrupt the adapter (odd) 
 */
/* ISRA even register controlled by adapter */
#define PARITY_ERR    0x80  /* Internal adapter parity error */ 
#define TIMER_STAT    0x40  /* TCR-odd timer has an interrupt for adapter */
#define ACCESS_STAT   0x20  /* Shared-ram or MMIO access violation */ 
#define DEADMAN       0x10  /* Microcode failure */
#define ADAPTER_CHK   0x08  /* Adapter processor failure */
#define H_INT_MASK    0x02  /* Mask hardware interrupts */
#define S_INT_MASK    0x01  /* Mask software interrupts */

/* ISRA odd register controlled by driver */
#define BFF_REQ       0x40  /* Bridge frame forward request */ 
#define FPT_REQ       0x40  /* Fast path transmit request */
#define CMD_IN_SRB    0x20  /* Inform adapter of command in SRB */
#define RESP_IN_ASB   0x10  /* Inform adapter of response in ASB */
#define SRB_FREE      0x08  /* Request SRB be freed */
#define ASB_FREE      0x04  /* Request ASB be freed */
#define ARB_FREE      0x02  /* Inform adapter that ARB has been freed */
#define SSB_FREE      0x01  /* Inform adapter that SSB has been freed */


/*
 * Interrupt Status Register PC System pair (ISRP)
 *    used by the adapter to interrupt the driver
 */
/* Even register */
#define CHCK_IRQ      0x80  /* Error interrupt control */
#define INT_ENABLE    0x40  /* Enable interrupts to workstation */
#define TVR_INT       0x10  /* TVR timer has expired */
#define ERR_INT       0x08  /* Adapter Check, Deadman or timer overrun */
#define ACCESS_INT    0x04  /* Access violation has occoured */
#define INT_BLOCK     0x02  /* Interrupt block bit */
#define PRI_ALT_ADAPT 0x01  /* Primary / Alternate select bit */

/* Odd Register */
#define ADAPT_CHK_INT 0x40  /* Adapter has a check condition */
#define SRB_RESP_INT  0x20  /* SRB command has return code set */
#define ASB_FREE_INT  0x10  /* ASB has been freed by the adapter */
#define ARB_REQ_INT   0x08  /* ARB is being requested by adapter */
#define SSB_RESP_INT  0x04  /* SSB has been returned by adapter */
#define BFF_COMP_INT  0x02  /* Bridge frame forward request complete */
#define FPT_COMP_INT  0x02  /* Fast path transmit complete */

/*
 * Timer Control Register pair (TCR)
 *    controls timing for the adapter and ring
 */
/* Even register only Odd register is reseved */
#define TCR_MASK      0x80  /* Enable TCR interrupts */
#define TCR_RELOAD    0x40  /* Reload TCR from TVR-odd */
#define TCR_GATE      0x20  /* Start - Stop TCR Timer */
#define TCR_OVERRUN   0x10  /* Indicates TCR overrun condition */
#define TCR_STATUS    0x08  /* Indicates non-zero value in TCR */
#define TCR_INTERLOCK 0x04  /* TCR locked for diagnostics */

/*
 * Adapter bring-up codes
 */

#define BUT_OK	          0x0000  /* Bring up tests ok */
#define BUT_DIAG_FAIL     0x0020  /* Diag failed to execute */
#define BUT_ROM_FAIL      0x0022  /* ROM(ROS) failed */
#define BUT_SRAM_FAIL     0x0024  /* SRAM tests failed */
#define BUT_PROC_FAIL     0x0026  /* Processor instruction test failed */
#define BUT_INT_FAIL      0x0028  /* Processor interrupt test failed */
#define BUT_REG_FAIL      0x002a  /* SRAM register test failed */
#define BUT_PROTO_FAIL    0x002c  /* Protocol handler test failed */
#define BUT_TIMER_FAIL    0x0040  /* Programmable timer test failed */
#define BUT_SRAM_RE       0x0042  /* SRAM Write failure */
#define BUT_SRAM_WE       0x0046  /* SRAM Read failure */
#define BUT_SRAM_WP       0x0046  /* SRAM write protection failure */
#define BUT_INIT_TIMEOUT  0x0048  /* Initialization  timed out */

/*
 * Adapter open options
 */
#define OPEN_WRAP               0x8000 /* Wrap interface for testing */
#define OPEN_DISABLE_HARD_ERR   0x4000 /* Disable hard error interrupts */
#define OPEN_DISABLE_SOFT_ERR   0x2000 /* Disable soft error interrupts */
#define OPEN_PASS_MAC_FRAMES    0x1000 /* Accept all adapter class MAC frames */
#define OPEN_PASS_ATTN_FRAMES   0x0800 /* Accept attention MAC frames */
#define OPEN_CONTENDER          0x0100 /* Enable ring monitor contention */
#define OPEN_PASS_BCON_FRAMES   0x0080 /* Accept beacon MAC frames */
#define OPEN_RPL                0x0020 /* Remote program locad */
#define OPEN_ETR                0x0010 /* Enable early token release */

/* 
 * Ring Status Bits 
 */
#define SIGNAL_LOSS      0x8000
#define HARD_ERR         0x4000
#define SOFT_ERR         0x2000
#define XMIT_BEACON      0x1000
#define WIRE_FAULT       0x0800
#define AUTO_REMOVAL     0x0400
#define REMOVE_REC       0x0100
#define COUNTER_OVERFLOW 0x0080
#define SINGLE_STATION   0x0040
#define RING_RECOVERY    0x0020

/*
 * Assorted Macros to help read-write shared ram locations 
 * and registers
 */

#define SRPR_MASK  0xc0
#define SRPR_SELECT(x)  (x<<6 & SRPR_MASK)  /* Page switch SRPR register */



